@@ -32,24 +32,6 @@
 
 #define GV_CLIENTLOGIN "https://www.google.com/accounts/ClientLogin"
 
-struct GVContactNumber
-{
-    GVContactNumber () : chType ('?') {}
-
-    QString strNumber;
-    char    chType;
-};
-
-struct GVContactInfo
-{
-    GVContactInfo () : selected(0) {}
-
-    QString                     strLink;
-    QString                     strName;
-    QVector<GVContactNumber>    arrPhones;
-    int                         selected;
-};
-
 struct GVRegisteredNumber
 {
     QString     strName;
@@ -79,6 +61,8 @@ struct GVInboxEntry
     QString         strPhoneNumber;
     QString         strText;
 
+    QString         strNote;
+
     bool            bRead;
     bool            bSpam;
     bool            bTrash;
@@ -93,6 +77,7 @@ struct GVInboxEntry
         strPhoneNumber.clear ();
         strDisplayNumber.clear ();
         strText.clear ();
+        strNote.clear ();
 
         startTime = QDateTime();
         Type = GVIE_Unknown;
@@ -132,10 +117,49 @@ struct PhoneInfo
     PhoneType   Type;
     QString     strNumber;
 
+    PhoneInfo() { init(); }
+
     void init () {
         Type = PType_Unknown;
         strNumber.clear ();
     }
+
+    static PhoneType charToType(const char ch) {
+        switch (ch) {
+        case 'M':
+            return PType_Mobile;
+        case 'H':
+            return PType_Home;
+        case 'O':
+            return PType_Other;
+        default:
+            return PType_Unknown;
+        }
+    }
+    static char typeToChar (PhoneType type) {
+        switch(type) {
+        case PType_Mobile:
+            return 'M';
+        case PType_Home:
+            return 'H';
+        case PType_Other:
+            return 'O';
+        default:
+            return '?';
+        }
+    }
+    static const char * typeToString (PhoneType type) {
+        switch(type) {
+        case PType_Mobile:
+            return "Mobile";
+        case PType_Home:
+            return "Home";
+        case PType_Other:
+            return "Other";
+        default:
+            return "Unknown";
+        }
+    }
 };
 typedef QVector<PhoneInfo> PhoneInfoArray;
 
@@ -145,17 +169,27 @@ struct ContactInfo
     QString         strId;
     //! Contact title a.k.a. the contact name
     QString         strTitle;
+
     //! Array of phones for this contact
     PhoneInfoArray  arrPhones;
+    // Which number is selected
+    int             selected;
+
+    //! The notes that the user may have added to the contact
+    QString         strNotes;
 
     //! Is this contact deleted?
     bool            bDeleted;
 
+    ContactInfo() { init(); }
+
     void init () {
         strId.clear ();
         strTitle.clear ();
         arrPhones.clear ();
+        strNotes.clear ();
         bDeleted = false;
+        selected = 0;
     }
 };
 Q_DECLARE_METATYPE(ContactInfo)
